==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/Effect/stereo/translations/stereo_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>EffectStereoFactory</name>
    <message>
        <location filename="../effectstereofactory.cpp" line="30"/>
        <source>Extra Stereo Plugin</source>
        <translation>立体声扩展插件</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="50"/>
        <source>About Extra Stereo Plugin</source>
        <translation>关于立体声扩展插件</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="51"/>
        <source>Qmmp Extra Stereo Plugin</source>
        <translation>Qmmp 立体声扩展插件</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="53"/>
        <source>Based on the Extra Stereo Plugin for Xmms by Johan Levin</source>
        <translation>基于 Johan Levin 的 Xmms 立体声扩展插件</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Extra Stereo Plugin Settings</source>
        <translation>立体声扩展插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="31"/>
        <source>Effect intensity:</source>
        <translation>效果强度：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="57"/>
        <source>%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_0.10.5.orig.tar.gz: qmmp-0.10.5/src/plugins/Effect/stereo/translations/stereo_plugin_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>EffectStereoFactory</name>
    <message>
        <location filename="../effectstereofactory.cpp" line="32"/>
        <source>Extra Stereo Plugin</source>
        <translation>立体声扩展插件</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="52"/>
        <source>About Extra Stereo Plugin</source>
        <translation>关于立体声扩展插件</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="53"/>
        <source>Qmmp Extra Stereo Plugin</source>
        <translation>Qmmp 立体声扩展插件</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="54"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../effectstereofactory.cpp" line="55"/>
        <source>Based on the Extra Stereo Plugin for Xmms by Johan Levin</source>
        <translation>基于 Johan Levin 的 Xmms 立体声扩展插件</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Extra Stereo Plugin Settings</source>
        <translation>立体声扩展插件设置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="31"/>
        <source>Effect intensity:</source>
        <translation>效果强度：</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="54"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="57"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
</context>
</TS>
